petab-select Python API
=======================

.. rubric:: Modules

.. autosummary::
   :toctree: generated

   petab_select
   petab_select.candidate_space
   petab_select.constants
   petab_select.criteria
   petab_select.handlers
   petab_select.misc
   petab_select.model
   petab_select.model_space
   petab_select.model_subspace
   petab_select.petab
   petab_select.plot
   petab_select.problem
   petab_select.ui
